
utils::globalVariables(c("V1", "V2", "coordinates", "data_value", "geolocation",
                         "high_confidence_limit",
                         "low_confidence_limit", "measures23", "measures22",
                         "measures21", "measures20",
                         "stateabbr", "release", "state_code",
                         "county_code", "county", "locationid", "locationname_p",
                         "locationname", "GEOID", "GEOID10", "countyname"))
